@@ -19,12 +19,19 @@
 
 """Integration tests for various transaction settlement skill's failure modes."""
 
-from pathlib import Path
 from typing import Any
 
-from aea_test_autonomy.fixture_helpers import HardHatAMMBaseTest
 from aea_test_autonomy.helpers.contracts import get_register_contract
 
+from packages.valory.contracts.multisend.tests.test_contract import (
+    PACKAGE_DIR as MULTISEND_PACKAGE,
+)
+from packages.valory.contracts.uniswap_v2_erc20.tests.test_contract import (
+    PACKAGE_DIR as UNISWAP_V2_ERC20_PACKAGE,
+)
+from packages.valory.contracts.uniswap_v2_router_02.tests.test_contract import (
+    PACKAGE_DIR as UNISWAP_V2_ROUTER_02_PACKAGE,
+)
 from packages.valory.skills.abstract_round_abci.test_tools.integration import (
     _HarHatHelperIntegration,
 )
@@ -36,24 +43,19 @@ from packages.valory.skills.transaction_settlement_abci.test_tools.integration i
 # pylint: disable=protected-access,too-many-ancestors,unbalanced-tuple-unpacking,too-many-locals,consider-using-with,unspecified-encoding,too-many-arguments,unidiomatic-typecheck
 
 
-class AMMIntegrationBaseCase(
-    _TxHelperIntegration, _HarHatHelperIntegration, HardHatAMMBaseTest
-):
+class AMMIntegrationBaseCase(_TxHelperIntegration, _HarHatHelperIntegration):
     """Base test class for integration tests in a Hardhat environment, with AMM interaction."""
 
     @classmethod
-    def setup(cls, **kwargs: Any) -> None:
+    def _setup_class(cls, **setup_class_kwargs: Any) -> None:
+        """Continue setting up the class."""
+
+    @classmethod
+    def setup_class(cls, **kwargs: Any) -> None:
         """Setup."""
-        super().setup()
+        super().setup_class()
 
         # register all contracts we need
-        directory = Path(
-            cls.ROOT_DIR, "packages", "valory", "contracts", "uniswap_v2_router_02"
-        )
-        _ = get_register_contract(directory)
-        directory = Path(
-            cls.ROOT_DIR, "packages", "valory", "contracts", "uniswap_v2_erc20"
-        )
-        _ = get_register_contract(directory)
-        directory = Path(cls.ROOT_DIR, "packages", "valory", "contracts", "multisend")
-        _ = get_register_contract(directory)
+        _ = get_register_contract(UNISWAP_V2_ROUTER_02_PACKAGE)
+        _ = get_register_contract(UNISWAP_V2_ERC20_PACKAGE)
+        _ = get_register_contract(MULTISEND_PACKAGE)
