@@ -36,9 +36,8 @@ from autonomy.deploy.constants import (
     TM_STATE_DIR,
 )
 from autonomy.replay.tendermint import TendermintNetwork
-from autonomy.test_tools.docker.base import skip_docker_tests
 
-from tests.conftest import ROOT_DIR
+from tests.conftest import ROOT_DIR, skip_docker_tests
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
